# HTCondor Job for Filesystem testing

The script `fstester` performs I/O operations on a filesystem mounted on HTCondor Worker Nodes.
Required arguments are filesystem path, maximum runtime and I/O operations mode:
```
./fstester -h
usage: fstester [-h] [-t TIME] [-f FS] (--casual | --read | --write)

Test a filesystem running I/O operations.

optional arguments:
  -h, --help            show this help message and exit
  -t TIME, --time TIME  maximum script runtime in s
  -f FS, --fs FS        filesystem location
  --casual              runs random I/O operations
  --read                runs random read operations
  --write               runs random write operations
```
The script can be run as a HTCondor job by submitting with the HTCondor file `fstester.sub`, e.g.:
```
[ffornari@ui-cdf ceph]$ cat fstester.sub 
# Job Executable
Executable      = fstester
# Script Arguments - Filesystem, Runtime, Ops Type
Arguments       = "-f /storage/gpfs_cdf0/users/ffornari -t 30 --write"
# HTCondor Job Type
Universe        = vanilla
# Job Output Files
Log             = log.txt
Output          = output.txt
Error           = error.txt
# Job Files Transfer Options
should_transfer_files = YES
when_to_transfer_output = ON_EXIT
# Number of Jobs to be Submitted
Queue 1
[ffornari@ui-cdf ceph]$ condor_submit -spool -name sn-02.cr.cnaf.infn.it fstester.sub
Submitting job(s).
1 job(s) submitted to cluster 145.
[ffornari@ui-cdf ceph]$ condor_q -name sn-02.cr.cnaf.infn.it 145


-- Schedd: sn-02.cr.cnaf.infn.it : <131.154.192.42:9618?... @ 10/21/20 17:43:15
OWNER    BATCH_NAME    SUBMITTED   DONE   RUN    IDLE  TOTAL JOB_IDS
ffornari ID: 145     10/21 17:43      _      _      1      1 145.0

Total for query: 1 jobs; 0 completed, 0 removed, 1 idle, 0 running, 0 held, 0 suspended 
Total for all users: 8 jobs; 7 completed, 0 removed, 1 idle, 0 running, 0 held, 0 suspended

[ffornari@ui-cdf ceph]$ condor_q -name sn-02.cr.cnaf.infn.it 145


-- Schedd: sn-02.cr.cnaf.infn.it : <131.154.192.42:9618?... @ 10/21/20 17:43:25
OWNER    BATCH_NAME    SUBMITTED   DONE   RUN    IDLE  TOTAL JOB_IDS
ffornari ID: 145     10/21 17:43      _      1      _      1 145.0

Total for query: 1 jobs; 0 completed, 0 removed, 0 idle, 1 running, 0 held, 0 suspended 
Total for all users: 8 jobs; 7 completed, 0 removed, 0 idle, 1 running, 0 held, 0 suspended

[ffornari@ui-cdf ceph]$ condor_q -name sn-02.cr.cnaf.infn.it 145


-- Schedd: sn-02.cr.cnaf.infn.it : <131.154.192.42:9618?... @ 10/21/20 17:43:58
OWNER    BATCH_NAME    SUBMITTED   DONE   RUN    IDLE  TOTAL JOB_IDS
ffornari ID: 145     10/21 17:43      _      _      _      1 145.0

Total for query: 1 jobs; 1 completed, 0 removed, 0 idle, 0 running, 0 held, 0 suspended 
Total for all users: 8 jobs; 8 completed, 0 removed, 0 idle, 0 running, 0 held, 0 suspended

[ffornari@ui-cdf ceph]$ condor_transfer_data -name sn-02.cr.cnaf.infn.it 145
Fetching data files...
[ffornari@ui-cdf ceph]$ ls
error.txt  fstester  fstester.sub  log.txt  output.txt
[ffornari@ui-cdf ceph]$ cat output.txt 
2020-10-21T17:43:26+0000 op_write function took 593.333 ms with return code None
2020-10-21T17:43:27+0000 op_write function took 217.267 ms with return code None
2020-10-21T17:43:27+0000 op_write function took 209.009 ms with return code None
2020-10-21T17:43:28+0000 op_write function took 235.683 ms with return code None
2020-10-21T17:43:28+0000 op_write function took 100.649 ms with return code None
2020-10-21T17:43:28+0000 op_write function took 142.216 ms with return code None
2020-10-21T17:43:28+0000 op_write function took 250.571 ms with return code None
2020-10-21T17:43:28+0000 op_write function took 225.615 ms with return code None
2020-10-21T17:43:28+0000 op_write function took 545.393 ms with return code None
2020-10-21T17:43:29+0000 op_write function took 217.467 ms with return code None
2020-10-21T17:43:29+0000 op_write function took 225.701 ms with return code None
2020-10-21T17:43:29+0000 op_write function took 292.213 ms with return code None
2020-10-21T17:43:30+0000 op_write function took 202.581 ms with return code None
2020-10-21T17:43:30+0000 op_write function took 350.630 ms with return code None
2020-10-21T17:43:30+0000 op_write function took 125.628 ms with return code None
2020-10-21T17:43:30+0000 op_write function took 1026.768 ms with return code None
2020-10-21T17:43:31+0000 op_write function took 377.615 ms with return code None
2020-10-21T17:43:32+0000 op_write function took 308.931 ms with return code None
2020-10-21T17:43:32+0000 op_write function took 200.812 ms with return code None
2020-10-21T17:43:32+0000 op_write function took 268.120 ms with return code None
2020-10-21T17:43:33+0000 op_write function took 719.349 ms with return code None
2020-10-21T17:43:33+0000 op_write function took 158.877 ms with return code None
2020-10-21T17:43:33+0000 op_write function took 183.803 ms with return code None
2020-10-21T17:43:34+0000 op_write function took 109.110 ms with return code None
2020-10-21T17:43:34+0000 op_write function took 558.982 ms with return code None
2020-10-21T17:43:34+0000 op_write function took 203.606 ms with return code None
2020-10-21T17:43:35+0000 op_write function took 317.052 ms with return code None
2020-10-21T17:43:35+0000 op_write function took 259.111 ms with return code None
2020-10-21T17:43:35+0000 op_write function took 342.338 ms with return code None
2020-10-21T17:43:35+0000 op_write function took 227.622 ms with return code None
2020-10-21T17:43:36+0000 op_write function took 242.310 ms with return code None
2020-10-21T17:43:36+0000 op_write function took 534.111 ms with return code None
2020-10-21T17:43:36+0000 op_write function took 233.942 ms with return code None
2020-10-21T17:43:37+0000 op_write function took 186.895 ms with return code None
2020-10-21T17:43:37+0000 op_write function took 217.320 ms with return code None
2020-10-21T17:43:37+0000 op_write function took 250.608 ms with return code None
2020-10-21T17:43:37+0000 op_write function took 1125.701 ms with return code None
2020-10-21T17:43:38+0000 op_write function took 235.891 ms with return code None
2020-10-21T17:43:39+0000 op_write function took 1235.043 ms with return code None
2020-10-21T17:43:40+0000 op_write function took 1950.534 ms with return code None
2020-10-21T17:43:42+0000 op_write function took 150.697 ms with return code None
2020-10-21T17:43:42+0000 op_write function took 247.401 ms with return code None
2020-10-21T17:43:42+0000 op_write function took 815.000 ms with return code None
2020-10-21T17:43:43+0000 op_write function took 1208.719 ms with return code None
2020-10-21T17:43:44+0000 op_write function took 908.906 ms with return code None
2020-10-21T17:43:45+0000 op_write function took 850.575 ms with return code None
2020-10-21T17:43:46+0000 op_write function took 477.670 ms with return code None
2020-10-21T17:43:47+0000 op_write function took 242.172 ms with return code None
2020-10-21T17:43:47+0000 op_write function took 200.865 ms with return code None
2020-10-21T17:43:47+0000 op_write function took 217.117 ms with return code None
2020-10-21T17:43:47+0000 op_write function took 253.433 ms with return code None
2020-10-21T17:43:47+0000 op_write function took 175.469 ms with return code None
2020-10-21T17:43:48+0000 op_write function took 258.928 ms with return code None
2020-10-21T17:43:48+0000 op_write function took 209.120 ms with return code None
2020-10-21T17:43:48+0000 op_write function took 142.430 ms with return code None
2020-10-21T17:43:48+0000 op_write function took 177.756 ms with return code None
2020-10-21T17:43:48+0000 op_write function took 183.991 ms with return code None
2020-10-21T17:43:49+0000 op_write function took 259.856 ms with return code None
2020-10-21T17:43:49+0000 op_write function took 175.674 ms with return code None
2020-10-21T17:43:49+0000 op_write function took 310.708 ms with return code None
2020-10-21T17:43:49+0000 op_write function took 268.322 ms with return code None
2020-10-21T17:43:50+0000 op_write function took 608.898 ms with return code None
2020-10-21T17:43:50+0000 op_write function took 283.918 ms with return code None
2020-10-21T17:43:51+0000 op_write function took 277.912 ms with return code None
2020-10-21T17:43:51+0000 op_write function took 1417.439 ms with return code None
2020-10-21T17:43:52+0000 op_write function took 192.312 ms with return code None
2020-10-21T17:43:52+0000 op_write function took 175.628 ms with return code None
2020-10-21T17:43:53+0000 op_write function took 194.915 ms with return code None
2020-10-21T17:43:53+0000 op_write function took 217.159 ms with return code None
2020-10-21T17:43:53+0000 op_write function took 242.289 ms with return code None
2020-10-21T17:43:53+0000 op_write function took 184.134 ms with return code None
2020-10-21T17:43:53+0000 op_write function took 1975.762 ms with return code None
2020-10-21T17:43:55+0000 op_write function took 169.554 ms with return code None
2020-10-21T17:43:56+0000 op_write function took 1567.278 ms with return code None
[ffornari@ui-cdf ceph]$ ls -lrth /storage/gpfs_cdf0/users/ffornari/
total 3,7G
-rw-r--r-- 1 ffornari ffornari  89M Oct 21 17:43 nV0NvoAyLPcx_1D2RqETaZujgUsJm
-rw-r--r-- 1 ffornari ffornari 5,6M Oct 21 17:43 _NuzKYGi1WpvosSTLdxI
-rw-r--r-- 1 ffornari ffornari 3,6M Oct 21 17:43 6M5XfPRcZ8xYmaj217ikrVd
-rw-r--r-- 1 ffornari ffornari  29M Oct 21 17:43 ku7GU4_x
-rw-r--r-- 1 ffornari ffornari 2,1M Oct 21 17:43 Lx4F_VnThm6Mfd70NpD3
-rw-r--r-- 1 ffornari ffornari  20M Oct 21 17:43 AjKzORubNnigMYDV9q25Ledt8h3cWl4Bf1SF7QZx
-rw-r--r-- 1 ffornari ffornari  71M Oct 21 17:43 rOaij5SqXmvDnceU2Qgx0pzJCALw
-rw-r--r-- 1 ffornari ffornari  72M Oct 21 17:43 NnJRlAsZ6vOe5gIQqyXLHT9VcdCFihGf
-rw-r--r-- 1 ffornari ffornari  98M Oct 21 17:43 S6_uAwbXP1OhGa
-rw-r--r-- 1 ffornari ffornari  17M Oct 21 17:43 YJKlrPSUAfDEy3xiIdNbm6oc2Ht
-rw-r--r-- 1 ffornari ffornari  23M Oct 21 17:43 Be0wR2F
-rw-r--r-- 1 ffornari ffornari  52M Oct 21 17:43 UFXCsvGmiO73kwqrEHYh_NePf
-rw-r--r-- 1 ffornari ffornari  43M Oct 21 17:43 HYT6bfiBdZ7
-rw-r--r-- 1 ffornari ffornari  95M Oct 21 17:43 FTV2hEz1Mnva6K
-rw-r--r-- 1 ffornari ffornari  19M Oct 21 17:43 pYUN0x8yloAG_F75bcgtjXuLH9WTfRa3QMDkZ
-rw-r--r-- 1 ffornari ffornari  86M Oct 21 17:43 OCdLDIrvVT6yKeoJ27GnBhMwtf4F9PbRjxk_
-rw-r--r-- 1 ffornari ffornari  84M Oct 21 17:43 6W0opgmX2zSMr49y
-rw-r--r-- 1 ffornari ffornari  54M Oct 21 17:43 dNO4taB
-rw-r--r-- 1 ffornari ffornari  11M Oct 21 17:43 h_AF
-rw-r--r-- 1 ffornari ffornari  36M Oct 21 17:43 tLyUcmSIRE1ewD
-rw-r--r-- 1 ffornari ffornari  91M Oct 21 17:43 wqPC3eK6lUR_yo0AJIE9
-rw-r--r-- 1 ffornari ffornari  32M Oct 21 17:43 sWZbcrJ_pdUQXES1MAx
-rw-r--r-- 1 ffornari ffornari  41M Oct 21 17:43 EHXBCRAG5Tiv4L0OsFnw9xQo6fJPh3
-rw-r--r-- 1 ffornari ffornari 5,6M Oct 21 17:43 MKW8xfRJnPuyzG0THbU4r6ZVgmhsqXwejCQl_
-rw-r--r-- 1 ffornari ffornari  82M Oct 21 17:43 E3yO_m2KXjIMArsq
-rw-r--r-- 1 ffornari ffornari 689K Oct 21 17:43 Pa8uY9oZJXSN4eUBqFn1zilywhI
-rw-r--r-- 1 ffornari ffornari  52M Oct 21 17:43 PBno7_uS3L16G4qZHiRfAVlxYE2mIwQO
-rw-r--r-- 1 ffornari ffornari  33M Oct 21 17:43 V1nrRzuDoT
-rw-r--r-- 1 ffornari ffornari  62M Oct 21 17:43 yzsDQlXAUS5WZbjP4TqeBO_Vw32
-rw-r--r-- 1 ffornari ffornari  46M Oct 21 17:43 YPACgSLZTQv53pW4MlJVaUh0qo
-rw-r--r-- 1 ffornari ffornari  57M Oct 21 17:43 4cuISDyNnbY6Cx1eFlgjL
-rw-r--r-- 1 ffornari ffornari  89M Oct 21 17:43 lSaqvH4C_rjAOE76MQxhTVGuf0ctZDR3L9obp
-rw-r--r-- 1 ffornari ffornari  64M Oct 21 17:43 jZY7EHeLCsXSDfRUiB4ycI
-rw-r--r-- 1 ffornari ffornari  32M Oct 21 17:43 zMRmxTQUbk
-rw-r--r-- 1 ffornari ffornari 8,0M Oct 21 17:43 AYT08
-rw-r--r-- 1 ffornari ffornari  25M Oct 21 17:43 Kkn4VbaUitGYhpvErSXOPBTfu0m2wy6NH9czDe
-rw-r--r-- 1 ffornari ffornari  95M Oct 21 17:43 Pvi_1WZIXHpgY37JCGNFh5kybdLtMxc20u
-rw-r--r-- 1 ffornari ffornari  33M Oct 21 17:43 6mkdLwqleT
-rw-r--r-- 1 ffornari ffornari  79M Oct 21 17:43 M_EY5f8VRzycBp6k1m2GH7xr
-rw-r--r-- 1 ffornari ffornari  79M Oct 21 17:43 Y_3Qw4LztWkJgsI
-rw-r--r-- 1 ffornari ffornari  32M Oct 21 17:43 gcNVwUJm6rMuFqSi
-rw-r--r-- 1 ffornari ffornari  77M Oct 21 17:43 xUQACuH4wDjEznrBaYig6RhpVe7vL0k
-rw-r--r-- 1 ffornari ffornari  82M Oct 21 17:43 vxCoR1GK2OJDUmyWTr_sdE34i
-rw-r--r-- 1 ffornari ffornari 100M Oct 21 17:43 gp41_c58Ro7KG
-rw-r--r-- 1 ffornari ffornari  99M Oct 21 17:43 cGJZd2io5tNwV9k7BQCr_ORDpz
-rw-r--r-- 1 ffornari ffornari  93M Oct 21 17:43 JKUD01HTFIl_ANrc9Oe8uVyGd4zmXQfxwWst
-rw-r--r-- 1 ffornari ffornari  78M Oct 21 17:43 WJ7d5Zp9rbmBUinDNClAo86tawy1
-rw-r--r-- 1 ffornari ffornari  42M Oct 21 17:43 Vo3wN48LfFEUm2M7sv0I_jqxyzSn6eADbugWYB
-rw-r--r-- 1 ffornari ffornari  29M Oct 21 17:43 zmquEx5erP
-rw-r--r-- 1 ffornari ffornari  29M Oct 21 17:43 QeZY5q7E89WRsIlVC_XnFDv
-rw-r--r-- 1 ffornari ffornari  47M Oct 21 17:43 kiSH9o5yJdpxTuGKR3hLIV0v_c2Z
-rw-r--r-- 1 ffornari ffornari  35M Oct 21 17:43 tY1Lhi6VgblIOMCd0QXA82GTy
-rw-r--r-- 1 ffornari ffornari  64M Oct 21 17:43 FCEcitrwz5A4ylISQfoJ0KG
-rw-r--r-- 1 ffornari ffornari  60M Oct 21 17:43 QL3tcoEZT
-rw-r--r-- 1 ffornari ffornari 5,2M Oct 21 17:43 m6LZnWaotc_M7Idsp9qQbXvxPuwBJkHz0OAy
-rw-r--r-- 1 ffornari ffornari  13M Oct 21 17:43 hFLP6KaUicSInXlE
-rw-r--r-- 1 ffornari ffornari  13M Oct 21 17:43 LBP_3iVZlGfNC8ny6qKOhX9eWTg
-rw-r--r-- 1 ffornari ffornari  62M Oct 21 17:43 ATEc6Ob2ULCHBy1MV_WYvzDIgXrt4oFfjQ5eJ
-rw-r--r-- 1 ffornari ffornari 6,7M Oct 21 17:43 14dIpb8_JMN9nLFBiCeGvHVgEsAyfO
-rw-r--r-- 1 ffornari ffornari  62M Oct 21 17:43 vRdCjtsYlXLND4ecpVi0oHO
-rw-r--r-- 1 ffornari ffornari  65M Oct 21 17:43 jSxnRzioqyKc5lV4d6wE9Us3e_gGTAmOk
-rw-r--r-- 1 ffornari ffornari  79M Oct 21 17:43 _oA6lriYFH8k
-rw-r--r-- 1 ffornari ffornari  76M Oct 21 17:43 lKV9upBCGLQHeynX4JwR
-rw-r--r-- 1 ffornari ffornari  66M Oct 21 17:43 J1y5OWn9c
-rw-r--r-- 1 ffornari ffornari 100M Oct 21 17:43 lSDwdza9
-rw-r--r-- 1 ffornari ffornari  13M Oct 21 17:43 cX7dTv1FrJKgVtAq2
-rw-r--r-- 1 ffornari ffornari  11M Oct 21 17:43 OqUsdZ4cxHViWfwjmFQJ2L
-rw-r--r-- 1 ffornari ffornari  29M Oct 21 17:43 ARST4Lf5piWhyN0ugEr3dtBIbvOjwM8qoXzQDK
-rw-r--r-- 1 ffornari ffornari  57M Oct 21 17:43 aXS_Yig
-rw-r--r-- 1 ffornari ffornari  73M Oct 21 17:43 dPHTbwl8kKJx3m2BSLCuYt4f_91VphUNX7FG
-rw-r--r-- 1 ffornari ffornari  41M Oct 21 17:43 ohuXRNaZ2
-rw-r--r-- 1 ffornari ffornari  89M Oct 21 17:43 EdK5NChXQ
-rw-r--r-- 1 ffornari ffornari 4,3M Oct 21 17:43 A6rhTMywfCuFzqkJ
-rw-r--r-- 1 ffornari ffornari  82M Oct 21 17:43 tl_uh02JvUOeAqaSF4RDQMpECyXk17zN
[ffornari@ui-cdf ceph]$
```
